<?php

namespace Litecms\Offer\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Offer\Interfaces\FlyerRepositoryInterface;

class FlyerPublicController extends BaseController
{
    // use FlyerWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Flyer\Interfaces\FlyerRepositoryInterface $flyer
     *
     * @return type
     */
    public function __construct(FlyerRepositoryInterface $flyer)
    {
        $this->repository = $flyer;
        parent::__construct();
    }

    /**
     * Show flyer's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $flyers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$offer::$flyer.names'))
            ->view('$offer::public.flyer.index')
            ->data(compact('$flyers'))
            ->output();
    }

    /**
     * Show flyer's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $flyers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$offer::$flyer.names'))
            ->view('$offer::public.flyer.index')
            ->data(compact('$flyers'))
            ->output();
    }

    /**
     * Show flyer.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $flyer = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$flyer->name . trans('$offer::$flyer.name'))
            ->view('$offer::public.flyer.show')
            ->data(compact('$flyer'))
            ->output();
    }

}
