<?php

namespace Litecms\Offer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Offer\Models\Shop;

class ShopPolicy
{

    /**
     * Determine if the given user can view the shop.
     *
     * @param UserPolicy $user
     * @param Shop $shop
     *
     * @return bool
     */
    public function view(UserPolicy $user, Shop $shop)
    {
        if ($user->canDo('offer.shop.view') && $user->isAdmin()) {
            return true;
        }

        return $shop->user_id == user_id() && $shop->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shop.
     *
     * @param UserPolicy $user
     * @param Shop $shop
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('offer.shop.create');
    }

    /**
     * Determine if the given user can update the given shop.
     *
     * @param UserPolicy $user
     * @param Shop $shop
     *
     * @return bool
     */
    public function update(UserPolicy $user, Shop $shop)
    {
        if ($user->canDo('offer.shop.edit') && $user->isAdmin()) {
            return true;
        }

        return $shop->user_id == user_id() && $shop->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shop.
     *
     * @param UserPolicy $user
     * @param Shop $shop
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Shop $shop)
    {
        return $shop->user_id == user_id() && $shop->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shop.
     *
     * @param UserPolicy $user
     * @param Shop $shop
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Shop $shop)
    {
        if ($user->canDo('offer.shop.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shop.
     *
     * @param UserPolicy $user
     * @param Shop $shop
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Shop $shop)
    {
        if ($user->canDo('offer.shop.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
