<?php

namespace Litecms\Offer\Providers;

use Illuminate\Support\ServiceProvider;

class OfferServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'offer');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'offer');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.offer', function ($app) {
            return $this->app->make('Litecms\Offer\Offer');
        });

        // Bind Category to repository
        $this->app->bind(
            'Litecms\Offer\Interfaces\CategoryRepositoryInterface',
            \Litecms\Offer\Repositories\Eloquent\CategoryRepository::class
        );
        // Bind Product to repository
        $this->app->bind(
            'Litecms\Offer\Interfaces\ProductRepositoryInterface',
            \Litecms\Offer\Repositories\Eloquent\ProductRepository::class
        );
        // Bind Shop to repository
        $this->app->bind(
            'Litecms\Offer\Interfaces\ShopRepositoryInterface',
            \Litecms\Offer\Repositories\Eloquent\ShopRepository::class
        );
        // Bind Offer to repository
        $this->app->bind(
            'Litecms\Offer\Interfaces\OfferRepositoryInterface',
            \Litecms\Offer\Repositories\Eloquent\OfferRepository::class
        );
        // Bind Flyer to repository
        $this->app->bind(
            'Litecms\Offer\Interfaces\FlyerRepositoryInterface',
            \Litecms\Offer\Repositories\Eloquent\FlyerRepository::class
        );

        $this->app->register(\Litecms\Offer\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Offer\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.offer'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/offer.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/offer')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/offer')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
