<?php

namespace Litecms\Offer\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litecms\Offer\Models\Offer;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\Offer\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/offer/category/*')) {
            Route::bind('category', function ($category) {
                $categoryrepo = $this->app->make('Litecms\Offer\Interfaces\CategoryRepositoryInterface');
                return $categoryrepo->findorNew($category);
            });
        }

        if (Request::is('*/offer/product/*')) {
            Route::bind('product', function ($product) {
                $productrepo = $this->app->make('Litecms\Offer\Interfaces\ProductRepositoryInterface');
                return $productrepo->findorNew($product);
            });
        }

        if (Request::is('*/offer/shop/*')) {
            Route::bind('shop', function ($shop) {
                $shoprepo = $this->app->make('Litecms\Offer\Interfaces\ShopRepositoryInterface');
                return $shoprepo->findorNew($shop);
            });
        }

        if (Request::is('*/offer/offer/*')) {
            Route::bind('offer', function ($offer) {
                $offerrepo = $this->app->make('Litecms\Offer\Interfaces\OfferRepositoryInterface');
                return $offerrepo->findorNew($offer);
            });
        }

        if (Request::is('*/offer/flyer/*')) {
            Route::bind('flyer', function ($flyer) {
                $flyerrepo = $this->app->make('Litecms\Offer\Interfaces\FlyerRepositoryInterface');
                return $flyerrepo->findorNew($flyer);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
